@@ -8,29 +8,31 @@ static USAGE_PART1: &str = "Usage:
   eza [options] [files...]
 
 META OPTIONS
-  --help             show list of command-line options
-  -v, --version      show version of eza
+  --help                     show list of command-line options
+  -v, --version              show version of eza
 
 DISPLAY OPTIONS
-  -1, --oneline      display one entry per line
-  -l, --long         display extended file metadata as a table
-  -G, --grid         display entries as a grid (default)
-  -x, --across       sort the grid across, rather than downwards
-  -R, --recurse      recurse into directories
-  -T, --tree         recurse into directories as a tree
-  -X, --dereference  dereference symbolic links when displaying information
-  -F, --classify     display type indicator by file names
-  --colo[u]r=WHEN    when to use terminal colours (always, auto, never)
-  --colo[u]r-scale   highlight levels of file sizes distinctly
-  --icons=WHEN       when to display icons (always, auto, never)
-  --no-quotes        don't quote file names with spaces
-  --hyperlink        display entries as hyperlinks
-  -w, --width COLS   set screen width in columns
-  --smart-group      only show group if it has a different name from owner
+  -1, --oneline              display one entry per line
+  -l, --long                 display extended file metadata as a table
+  -G, --grid                 display entries as a grid (default)
+  -x, --across               sort the grid across, rather than downwards
+  -R, --recurse              recurse into directories
+  -T, --tree                 recurse into directories as a tree
+  -X, --dereference          dereference symbolic links when displaying information
+  -F, --classify             display type indicator by file names
+  --colo[u]r=WHEN            when to use terminal colours (always, auto, never)
+  --colo[u]r-scale           highlight levels of 'field' distinctly(all, age, size)
+  --colo[u]r-scale-mode      use gradient or fixed colors in --color-scale (fixed, gradient)
+  --icons=WHEN               when to display icons (always, auto, never)
+  --no-quotes                don't quote file names with spaces
+  --hyperlink                display entries as hyperlinks
+  -w, --width COLS           set screen width in columns
+  --smart-group              only show group if it has a different name from owner
 
 
 FILTERING AND SORTING OPTIONS
-  -a, --all                  show hidden and 'dot' files. Use this twice to also show the '.' and '..' directories
+  -a, --all                  show hidden and 'dot' files. Use this twice to also
+                             show the '.' and '..' directories
   -A, --almost-all           equivalent to --all; included for compatibility with `ls -A`
   -d, --list-dirs            list directories as files; don't list their contents
   -L, --level DEPTH          limit the depth of recursion
@@ -50,36 +52,40 @@ static USAGE_PART2: &str = "  \
                              date, time, old, and new all refer to modified.
 
 LONG VIEW OPTIONS
-  -b, --binary             list file sizes with binary prefixes
-  -B, --bytes              list file sizes in bytes, without any prefixes
-  -g, --group              list each file's group
-  -h, --header             add a header row to each column
-  -H, --links              list each file's number of hard links
-  -i, --inode              list each file's inode number
-  -m, --modified           use the modified timestamp field
-  -M, --mounts             show mount details (Linux and MacOS only)
-  -n, --numeric            list numeric user and group IDs
-  -S, --blocksize          show size of allocated file system blocks
-  -t, --time FIELD         which timestamp field to list (modified, accessed, created)
-  -u, --accessed           use the accessed timestamp field
-  -U, --created            use the created timestamp field
-  --changed                use the changed timestamp field
-  --time-style             how to format timestamps (default, iso, long-iso, full-iso, relative, or a custom style with '+' as prefix. Ex: '+%Y/%m/%d')
-  --total-size             show the size of a directory as the size of all files and directories inside
-  --no-permissions         suppress the permissions field
-  -o, --octal-permissions  list each file's permission in octal format
-  --no-filesize            suppress the filesize field
-  --no-user                suppress the user field
-  --no-time                suppress the time field";
+  -b, --binary               list file sizes with binary prefixes
+  -B, --bytes                list file sizes in bytes, without any prefixes
+  -g, --group                list each file's group
+  -h, --header               add a header row to each column
+  -H, --links                list each file's number of hard links
+  -i, --inode                list each file's inode number
+  -m, --modified             use the modified timestamp field
+  -M, --mounts               show mount details (Linux and MacOS only)
+  -n, --numeric              list numeric user and group IDs
+  -S, --blocksize            show size of allocated file system blocks
+  -t, --time FIELD           which timestamp field to list (modified, accessed, created)
+  -u, --accessed             use the accessed timestamp field
+  -U, --created              use the created timestamp field
+  --changed                  use the changed timestamp field
+  --time-style               how to format timestamps (default, iso, long-iso,
+                             full-iso, relative, or a custom style with '+' as
+                             prefix. Ex: '+%Y/%m/%d')
+  --total-size               show the size of a directory as the size of all
+                             files and directories inside
+  --no-permissions           suppress the permissions field
+  -o, --octal-permissions    list each file's permission in octal format
+  --no-filesize              suppress the filesize field
+  --no-user                  suppress the user field
+  --no-time                  suppress the time field";
 
-static GIT_VIEW_HELP:   &str = "  \
-  --git                    list each file's Git status, if tracked or ignored
-  --no-git                 suppress Git status (always overrides --git, --git-repos, --git-repos-no-status)
-  --git-repos              list root of git-tree status";
+static GIT_VIEW_HELP: &str = "  \
+  --git                      list each file's Git status, if tracked or ignored
+  --no-git                   suppress Git status (always overrides --git,
+                             --git-repos, --git-repos-no-status)
+  --git-repos                list root of git-tree status";
 static EXTENDED_HELP: &str = "  \
-  -@, --extended           list each file's extended attributes and sizes";
+  -@, --extended             list each file's extended attributes and sizes";
 static SECATTR_HELP: &str = "  \
-  -Z, --context            list each file's security context";
+  -Z, --context              list each file's security context";
 
 /// All the information needed to display the help text, which depends
 /// on which features are enabled and whether the user only wants to
